==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Le mot de passe doit être au moins de %s caractères",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci de le rendre unique.",
    "Password policy" : "Politique de mots de passe",
    "Minimal length" : "Taille minimale",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Password need to be at least %s characters long" : "Le mot de passe doit être au moins de %s caractères",
    "Password need to contain at least one lower case character and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password need to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password need to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci d'en choisir un autre."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci de le rendre unique.",
    "Password policy" : "Politique de mots de passe",
    "Minimal length" : "Taille minimale",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Password need to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password need to contain at least one lower case character and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password need to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password need to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Le mot de passe se trouve parmi les 1 000 000 mots de passe les plus courants. Merci d'en choisir un autre."
},
"nplurals=2; plural=(n > 1);");
